@@ -12,17 +12,19 @@
 
 namespace KIMAP
 {
-
 class SessionPrivate;
 
 class JobPrivate
 {
 public:
-    JobPrivate(Session *session, const QString &name) : m_session(session)
+    JobPrivate(Session *session, const QString &name)
+        : m_session(session)
     {
         m_name = name;
     }
-    virtual ~JobPrivate() { }
+    virtual ~JobPrivate()
+    {
+    }
 
     inline SessionPrivate *sessionInternal()
     {
